[gnome-color-manager] Also evaluate /usr/local/bin when searching for Argyll tools. Fixes #605552
- From: Richard Hughes <rhughes src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [gnome-color-manager] Also evaluate /usr/local/bin when searching for Argyll tools. Fixes #605552
- Date: Mon, 28 Dec 2009 10:25:52 +0000 (UTC)
commit d6494f179c4ea9cfaedd887480d0269dfa41b320
Author: Pascal de Bruijn <pmjdebruijn pcode nl>
Date: Mon Dec 28 10:25:16 2009 +0000
Also evaluate /usr/local/bin when searching for Argyll tools. Fixes #605552
Signed-off-by: Richard Hughes <richard hughsie com>
src/gcm-calibrate-argyll.c | 11 +++++++++--
1 files changed, 9 insertions(+), 2 deletions(-)
---
diff --git a/src/gcm-calibrate-argyll.c b/src/gcm-calibrate-argyll.c
index 726a164..03631f6 100644
--- a/src/gcm-calibrate-argyll.c
+++ b/src/gcm-calibrate-argyll.c
@@ -192,13 +192,20 @@ gcm_calibrate_argyll_get_tool_filename (const gchar *command, GError **error)
gboolean ret;
gchar *filename;
- /* try the debian filename */
+ /* try the original argyllcms filename installed in /usr/local/bin */
+ filename = g_strdup_printf ("/usr/local/bin/%s", command);
+ ret = g_file_test (filename, G_FILE_TEST_EXISTS);
+ if (ret)
+ goto out;
+
+ /* try the debian filename installed in /usr/bin */
+ g_free (filename);
filename = g_strdup_printf ("/usr/bin/argyll-%s", command);
ret = g_file_test (filename, G_FILE_TEST_EXISTS);
if (ret)
goto out;
/* try the original argyllcms filename */
g_free (filename);
filename = g_strdup_printf ("/usr/bin/%s", command);
ret = g_file_test (filename, G_FILE_TEST_EXISTS);
@@ -192,13 +192,20 @@ gcm_calibrate_argyll_get_tool_filename (const gchar *command, GError **error)
if (ret)
goto out;
- /* try the original argyllcms filename */
+ /* try the original argyllcms filename installed in /usr/bin */
g_free (filename);
filename = g_strdup_printf ("/usr/bin/%s", command);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]